0.9.1-6 2015-02-18
------------------
Changed:    -
Added:      Automatic retires for hcpsdk.Connection.request() in case of a
            timeout or connection abort.
            A DummyAuthorization class for use with the Default Namespace
            An appendiy on the difference when working with the Default
            Namespace
Fixed:      -

Version Date
------------------
Changed:    -
Added:      -
Fixed:      -